@@ -24,10 +24,11 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.41';
+$VERSION = '1.43';
 
 sub ProcessKodakIFD($$$);
 sub ProcessKodakText($$$);
+sub ProcessPose($$$);
 sub WriteKodakIFD($$$);
 
 # Kodak type 1 maker notes (ref 1)
@@ -189,6 +190,7 @@ sub WriteKodakIFD($$$);
             1 => 'Flash?',
             2 => 'Tungsten',
             3 => 'Daylight',
+            # 5 - seen this for "Auto" with a ProBack 645M
         },
     },
     0x5c => {
@@ -856,6 +858,8 @@ sub WriteKodakIFD($$$);
         writable because the inconsistency of Kodak maker notes is beginning to get
         on my nerves.
     },
+    # (these are related to the Kodak QuickTime UserData tags)
+    0x0104 => 'FirmwareVersion',
     0x0203 => {
         Name => 'PictureEffect',
         PrintConv => {
@@ -869,6 +873,13 @@ sub WriteKodakIFD($$$);
     0x0300 => 'KodakMake',
     0x0308 => 'LensSerialNumber',
     0x0309 => 'LensModel',
+    0x030d => { Name => 'LevelMeter', Unknown => 1 }, # (guess)
+    0x0311 => 'Pitch', # Units??
+    0x0312 => 'Yaw',   # Units??
+    0x0313 => 'Roll',  # Units??
+    0x0314 => { Name => 'CX',   Unknown => 1 },
+    0x0315 => { Name => 'CY',   Unknown => 1 },
+    0x0316 => { Name => 'Rads', Unknown => 1 },
 );
 
 # Kodak SubIFD0 tags (ref PH)
@@ -1527,12 +1538,14 @@ my %sceneModeUsed = (
     'Exposure Mode' => {
         Name => 'ExposureMode',
         PrintConv => {
+            OTHER => sub { shift }, # pass other values straight through
             'M' => 'Manual',
             'A' => 'Aperture Priority', #(NC -- I suppose this could be "Auto" too)
             'S' => 'Shutter Priority', #(NC)
             'P' => 'Program', #(NC)
             'B' => 'Bulb', #(NC)
             # have seen "Manual (M)" written by DCS760C - PH
+            # and "Aperture priority AE (Av)" written by a ProBack 645M
         },
     },
     'Firmware Version' => 'FirmwareVersion',
@@ -1858,7 +1871,7 @@ my %sceneModeUsed = (
 %Image::ExifTool::Kodak::frea = (
     GROUPS => { 0 => 'MakerNotes', 2 => 'Image' },
     NOTES => 'Information stored in the "frea" atom of Kodak PixPro SP360 MP4 videos.',
-    # tima - 4 bytes: 0 0 0 0x20
+    # tima - 4 bytes: "0 0 0 0x20" or "0 0 0 0x0a"
     thma => { Name => 'ThumbnailImage', Groups => { 2 => 'Preview' }, Binary => 1 },
     scra => { Name => 'PreviewImage',   Groups => { 2 => 'Preview' }, Binary => 1 },
 );
@@ -1879,6 +1892,18 @@ my %sceneModeUsed = (
     },
 );
 
+# acceleration information extracted from 'pose' atom of MP4 videos (ref PH, PixPro 4KVR360)
+%Image::ExifTool::Kodak::pose = (
+    GROUPS => { 0 => 'MakerNotes', 2 => 'Video' },
+    PROCESS_PROC => \&ProcessPose,
+    NOTES => q{
+        Streamed orientation information from the PixPro 4KVR360, extracted as
+        sub-documents when the Duplicates option is used.
+    },
+    Accelerometer => { }, # up, back, left?  units of g
+    AngularVelocity => { } # left, up, ccw?  units?
+);
+
 # Kodak composite tags
 %Image::ExifTool::Kodak::Composite = (
     GROUPS => { 2 => 'Camera' },
@@ -1931,6 +1956,52 @@ my %sceneModeUsed = (
 # add our composite tags
 Image::ExifTool::AddCompositeTags('Image::ExifTool::Kodak');
 
+#------------------------------------------------------------------------------
+# Process Kodak accelerometer data (ref PH)
+# Inputs: 0) ExifTool ref, 1) dirInfo ref, 2) tag table ref
+# Returns: 1 on success
+sub ProcessPose($$$)
+{
+    my ($et, $dirInfo, $tagTablePtr) = @_;
+    my $dataPt = $$dirInfo{DataPt};
+    my $dirLen = length $$dataPt;
+    my $ee = $et->Options('ExtractEmbedded');
+    my ($i, $pos);
+
+    return 0 if $dirLen < 0x14;
+    my $num = Get32u($dataPt, 0x10);
+    return 0 if $dirLen < 0x14 + $num * 24;
+
+    $et->VerboseDir('Kodak pose', undef, $dirLen);
+
+    $$et{DOC_NUM} = 0;
+    for ($i=0, $pos=0x14; $i<$num; ++$i, $pos+=24) {
+        $et->HandleTag($tagTablePtr, AngularVelocity =>
+            Image::ExifTool::GetRational64s($dataPt, $pos) . ' ' .
+            Image::ExifTool::GetRational64s($dataPt, $pos + 8) . ' ' .
+            Image::ExifTool::GetRational64s($dataPt, $pos + 16));
+        $ee or $pos += $num * 24, last;
+        ++$$et{DOC_NUM};
+    }
+    $$et{DOC_NUM} = 0;
+
+    return 1 if $dirLen < $pos + 0x10;
+    $num = Get32u($dataPt, $pos + 0x0c);
+    return 1 if $dirLen < $pos + 0x10 + $num * 24;
+
+    for ($i=0, $pos+=0x10; $i<$num; ++$i, $pos+=24) {
+        $et->HandleTag($tagTablePtr, Accelerometer =>
+            Image::ExifTool::GetRational64s($dataPt, $pos) . ' ' .
+            Image::ExifTool::GetRational64s($dataPt, $pos + 8) . ' ' .
+            Image::ExifTool::GetRational64s($dataPt, $pos + 16));
+        $ee or $pos += $num * 24, last;
+        ++$$et{DOC_NUM};
+    }
+    $$et{DOC_NUM} = 0;
+    $ee or $et->Warn('Use the ExtractEmbedded option to extract all accelerometer data',3);
+    return 1;
+}
+
 #------------------------------------------------------------------------------
 # Calculate RGB levels from associated tags (ref 3)
 # Inputs: 0) KodakIFD:WhiteBalance, 1-4) WB_RGBMul0-3, 5-8) WB_RGBCoeffs0-3
@@ -2069,7 +2140,7 @@ interpret Kodak maker notes EXIF meta information.
 
 =head1 AUTHOR
 
-Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2018, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
