@@ -59,9 +59,10 @@ my $mpsToKph   = 3.6;   # m/s   --> km/h
 %Image::ExifTool::QuickTime::Stream = (
     GROUPS => { 2 => 'Location' },
     NOTES => q{
-        Timed metadata extracted from QuickTime movie data and BikeBro AVI videos
-        when the ExtractEmbedded option is used.
+        Timed metadata extracted from QuickTime movie data and some AVI videos when
+        the ExtractEmbedded option is used.
     },
+    VARS => { NO_ID => 1 },
     GPSLatitude  => { PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")' },
     GPSLongitude => { PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")' },
     GPSAltitude  => { PrintConv => '(sprintf("%.4f", $val) + 0) . " m"' }, # round to 4 decimals
@@ -71,13 +72,17 @@ my $mpsToKph   = 3.6;   # m/s   --> km/h
     GPSTrackRef  => { PrintConv => { M => 'Magnetic North', T => 'True North' } },
     GPSDateTime  => { PrintConv => '$self->ConvertDateTime($val)', Groups => { 2 => 'Time' } },
     Accelerometer=> { Notes => 'right/up/backward acceleration in units of g' },
+    RawGSensor    => {
+        # (same as GSensor, but offset by some unknown value)
+        ValueConv => 'my @a=split " ",$val; $_/=1000 foreach @a; "@a"',
+    },
     Text         => { Groups => { 2 => 'Other' } },
     TimeCode     => { Groups => { 2 => 'Video' } },
     FrameNumber  => { Groups => { 2 => 'Video' } },
     SampleTime   => { Groups => { 2 => 'Video' }, PrintConv => 'ConvertDuration($val)', Notes => 'sample decoding time' },
     SampleDuration=>{ Groups => { 2 => 'Video' }, PrintConv => 'ConvertDuration($val)' },
 #
-# timed metadata decoded based on MetaFormat (format of 'meta' sample description)
+# timed metadata decoded based on MetaFormat (format of 'meta' or 'data' sample description)
 # [or HandlerType, or specific 'vide' type if specified]
 #
     mebx => {
@@ -105,6 +110,22 @@ my $mpsToKph   = 3.6;   # m/s   --> km/h
         Name => 'CTMD',
         SubDirectory => { TagTable => 'Image::ExifTool::Canon::CTMD' },
     },
+    RVMI => [{ # data "OtherFormat" written by unknown software
+        Name => 'RVMI_gReV',
+        Condition => '$$valPt =~ /^gReV/',  # GPS data
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::QuickTime::RVMI_gReV',
+            ByteOrder => 'Little-endian',
+        },
+    },{
+        Name => 'RVMI_sReV',
+        Condition => '$$valPt =~ /^sReV/',  # sensor data
+        SubDirectory => {
+            TagTable => 'Image::ExifTool::QuickTime::RVMI_sReV',
+            ByteOrder => 'Little-endian',
+        },
+    # (there is also "tReV" data that hasn't been decoded yet)
+    }],
     camm => { # (written by Insta360) - [HandlerType, not MetaFormat]
         Name => 'camm6',
         Condition => '$$valPt =~ /^\0\0\x06\0/',
@@ -126,8 +147,8 @@ my $mpsToKph   = 3.6;   # m/s   --> km/h
     GROUPS => { 2 => 'Location' },
     FIRST_ENTRY => 0,
     NOTES => q{
-        These tags are extracted from record type 6 of the 'camm' timed metadata of
-        MP4 videos from the Insta360.
+        Tags extracted from record type 6 of the 'camm' timed metadata of MP4 videos
+        from cameras such as the Insta360.
     },
   # 0x0c - int32u, seen: 3 (GPSMeasureMode?)
     0x10 => {
@@ -150,6 +171,54 @@ my $mpsToKph   = 3.6;   # m/s   --> km/h
   # 0x30 - float (GPSSpeed?)
 );
 
+# tags found in 'RVMI' 'gReV' timed metadata (ref PH)
+%Image::ExifTool::QuickTime::RVMI_gReV = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    GROUPS => { 2 => 'Location' },
+    FIRST_ENTRY => 0,
+    NOTES => q{
+        GPS information extracted from the RVMI box of MOV videos.
+    },
+    4 => {
+        Name => 'GPSLatitude',
+        Format => 'int32s',
+        ValueConv => 'Image::ExifTool::GPS::ToDegrees($val/1e6, 1)',
+        PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "N")',
+    },
+    8 => {
+        Name => 'GPSLongitude',
+        Format => 'int32s',
+        ValueConv => 'Image::ExifTool::GPS::ToDegrees($val/1e6, 1)',
+        PrintConv => 'Image::ExifTool::GPS::ToDMS($self, $val, 1, "E")',
+    },
+    # 12 - int32s: space for altitude? (always zero in my sample)
+    16 => {
+        Name => 'GPSSpeed', # km/h
+        Format => 'int16s',
+        ValueConv => '$val / 10',
+    },
+    18 => {
+        Name => 'GPSTrack',
+        Format => 'int16u',
+        ValueConv => '$val * 2',
+    },
+);
+
+# tags found in 'RVMI' 'sReV' timed metadata (ref PH)
+%Image::ExifTool::QuickTime::RVMI_sReV = (
+    PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
+    GROUPS => { 2 => 'Location' },
+    FIRST_ENTRY => 0,
+    NOTES => q{
+        G-sensor information extracted from the RVMI box of MOV videos.
+    },
+    4 => {
+        Name => 'GSensor',
+        Format => 'int16s[3]', # X Y Z
+        ValueConv => 'my @a=split " ",$val; $_/=1000 foreach @a; "@a"',
+    },
+);
+
 #------------------------------------------------------------------------------
 # Save information from keys in OtherSampleDesc directory for processing timed metadata
 # Inputs: 0) ExifTool object ref, 1) dirInfo ref, 2) tag table ref
@@ -376,12 +445,27 @@ sub ProcessSamples($)
                     next if $size == 2;
                     $buff = substr($buff,2);
                 }
-                $et->HandleTag($tagTbl, Text => $buff);
-                next;
+                my $val;
+                # check for encrypted GPS text as written by E-PRANCE B47FS camera
+                if ($buff =~ /^\0/ and $buff =~ /\x0a$/ and length($buff) > 5) {
+                    # decode simple ASCII difference cipher,
+                    # based on known value of 4th-last char = '*'
+                    my $dif = ord('*') - ord(substr($buff, -4, 1));
+                    my $tmp = pack 'C*',map { $_=($_+$dif)&0xff } unpack 'C*',substr $buff,1,-1;
+                    if ($tmp =~ /^(.*?)(\$[A-Z]{2}RMC.*)/s) {
+                        ($val, $buff) = ($1, $2);
+                        $val =~ tr/\t/ /;
+                        $et->HandleTag($tagTbl, RawGSensor => $val) if length $val;
+                    }
+                }
+                unless (defined $val) {
+                    $et->HandleTag($tagTbl, Text => $buff); # just store any other text
+                    next;
+                }
             }
             while ($buff =~ /\$(\w+)([^\$]*)/g) {
                 my ($tag, $dat) = ($1, $2);
-                if ($tag eq 'GPRMC' and $dat =~ /^,(\d{2})(\d{2})(\d+(\.\d*)?),A?,(\d*?)(\d{1,2}\.\d+),([NS]),(\d*?)(\d{1,2}\.\d+),([EW]),(\d*\.?\d*),(\d*\.?\d*),(\d{2})(\d{2})(\d+)/) {
+                if ($tag =~ /^[A-Z]{2}RMC$/ and $dat =~ /^,(\d{2})(\d{2})(\d+(\.\d*)?),A?,(\d*?)(\d{1,2}\.\d+),([NS]),(\d*?)(\d{1,2}\.\d+),([EW]),(\d*\.?\d*),(\d*\.?\d*),(\d{2})(\d{2})(\d+)/) {
                     $et->HandleTag($tagTbl, GPSLatitude  => (($5 || 0) + $6/60) * ($7 eq 'N' ? 1 : -1));
                     $et->HandleTag($tagTbl, GPSLongitude => (($8 || 0) + $9/60) * ($10 eq 'E' ? 1 : -1));
                     if (length $11) {
@@ -406,7 +490,7 @@ sub ProcessSamples($)
                 }
             }
 
-        } elsif ($type eq 'meta') {
+        } elsif ($type eq 'meta' or $type eq 'data') {
 
             if ($$tagTbl{$metaFormat}) {
                 my $tagInfo = $et->GetTagInfo($tagTbl, $metaFormat, \$buff);
