@@ -19,7 +19,7 @@ use strict;
 use vars qw($VERSION $warnString);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.20';
+$VERSION = '1.21';
 
 sub WarnProc($) { $warnString = $_[0]; }
 
@@ -37,6 +37,12 @@ my %openDocType = (
     'application/epub+zip' => 'EPUB', #PH (not open doc)
 );
 
+# iWork file types based on names of files found in the zip archive
+my %iWorkFile = (
+    'Index/Slide.iwa' => 'KEY',
+    'Index/Tables/DataList.iwa' => 'NUMBERS',
+);
+
 # ZIP metadata blocks
 %Image::ExifTool::ZIP::Main = (
     PROCESS_PROC => \&Image::ExifTool::ProcessBinaryData,
@@ -375,7 +381,7 @@ sub ProcessZIP($$)
     my $raf = $$dirInfo{RAF};
     my ($buff, $buf2, $zip, $docNum);
 
-    return 0 unless $raf->Read($buff, 30) and $buff =~ /^PK\x03\x04/;
+    return 0 unless $raf->Read($buff, 30) == 30 and $buff =~ /^PK\x03\x04/;
 
     my $tagTablePtr = GetTagTable('Image::ExifTool::ZIP::Main');
 
@@ -552,11 +558,16 @@ sub ProcessZIP($$)
         $et->SetFileType();
         @members = $zip->members();
         $docNum = 0;
-        my $member;
+        my ($member, $iWorkType);
         # special files to extract
         my %extract = (
             'meta.json' => 1,
             'previews/preview.png' => 'PreviewPNG',
+            'preview.jpg' => 'PreviewImage', # (iWork 2013 files)
+            'preview-web.jpg' => 'OtherImage', # (iWork 2013 files)
+            'preview-micro.jpg' => 'ThumbnailImage', # (iWork 2013 files)
+            'QuickLook/Thumbnail.jpg' => 'ThumbnailImage', # (iWork 2009 files)
+            'QuickLook/Preview.pdf' => 'PreviewPDF', # (iWork 2009 files)
         );
         foreach $member (@members) {
             $$et{DOC_NUM} = ++$docNum;
@@ -574,8 +585,13 @@ sub ProcessZIP($$)
                 } else {
                     $et->FoundTag($extract{$file} => $buff);
                 }
+            } elsif ($file eq 'Index/Document.iwa' and not $iWorkType) {
+                $iWorkType = 'PAGES';
+            } elsif ($iWorkFile{$file}) {
+                $iWorkType = $iWorkFile{$file};
             }
         }
+        $et->OverrideFileType($iWorkType) if $iWorkType;
         last;
     }
     # all done if we processed this using Archive::Zip
